==> keyword-jquery-0.0.12.tgz: package/src/keyword-jquery.js <==
(function($) {
    $.fn.keyword = function(options) {
    	var isMobile = /iPhone|iPad|iPod|Android/i.test(navigator.userAgent);
    	
    	return this.each(function() {
    		var id = Math.random().toString(36).substring(4);
    		var select = $(this);
    		var list = [];
    		var keys = {};
    		var data = {};
    		var val = "";
    		var max = 10;
    		var url = 0;
    		var post_key = 0;
    		var mode = $(this).prop('multiple');
    		
			if(isMobile){
				
			} else {
				var h = "";
				$(select).find("option").each(function(i,o){
					var id = $(this).attr("value");
					var selected = ($(this).prop("selected")) ? 1 : 0;
					keys[id] =  selected;
					data[id] = {text:$(this).html(),id:id}
					list.push(data[id]);
					if(selected) h+="<option value='"+id+"' selected>"+data[id].text+"</option>";
				});	
				$(select).html(h);
				var selectHtml = "<span class='select-container'>Select item <input type='text'/></span>";
				select.after('<span class="keyword" id="select-'+id+'"></span>');
				select.css("position","absolute")
					.css("height","0")
					.css("opacity","0");
			}
			var container = $("#select-"+id);
    		
    		var app = {
				change:function(t){
					var v = (val) ? $(t).val() :  $(t).data('id');
					var attr = app.getAttr(t);
					app.update(attr);
				},
				update:function (o){
					var h = "";
					keys[o.id] = (keys[o.id]) ? 0 : 1;
					data[o.id] = o;
					
					var self = this;
					$.each(keys,function(id,active){
						if(!mode && (id!=o.id)) keys[id] = 0; 
						var attr = self.rendAttr(data[id]);
						if(active) h+= "<option value='"+id+"' "+attr+" selected>"+data[id].text+"</option>";
					});
					
					$(select).html(h);
					val = "";
					$(container).removeClass("active");
					app.resetInput();
					app.render();
				},
				remove:function (t){
					app.change(t);
				},
				render:function (){
					var htmlSelect = "";
					var htmlTags = "";
					var htmlList = "";
					var x = 0;
					var self = this;
					$.each(list,function(i,o){
						var attr = self.rendAttr(o);
						
						if(keys[o.id]) {
							htmlTags+="<span class='tag' "+attr+">"+o.text+" </span>"
						} else {
							if(x<max) htmlList+="<tr><td "+attr+">"+o.text+"</td></tr>";
							x++;
						}
					});	
					
					
					htmlSelect = "<span class='select-container'> <input type='text' placeholder='Select item'/></span><span class='select-dropdown'><table>"+htmlList+"</table></span>";	
					
					$(container).html(htmlTags+htmlSelect);
					$(container).find("input").focus(function(){
						var p = $(this).parent().parent();
						if(!$(p).hasClass("active")) $(p).addClass("active");
					});
					$(container).find("input").blur(function(){
						var p = $(this).parent().parent();
						$(p).removeClass("active");
						app.resetInput();
					});
					$(container).find("input").keyup(function(){
						var v = $(this).val().toLowerCase();
						if(val!=v) {
							val = v;
							if(post_key) {
								var p = {};
								p[post_key] = val;
								app.ajax(url,p,app.renderList);
							} else {
								app.renderList();
							}
							
						}
					});
					$(container).find(".select-dropdown td").on("mousedown", function(){
						app.change(this);
					});
					
					$(container).find(".tag").click(function(){
						app.remove(this);
					});
					
					$(container).find("input")
						//.css("opacity",0)
						.css("position","absolute")
						.css("width","100%")
						.css("left",0);
				},
				mobileRender:function(addListeners){
					var select = $(container).find("select");
					var ids = $(select).val();
					var tags = $(container).find(".tags");
					var h = "";
					$(select).find("option").each(function(i,o){
						if($(this).prop("selected")) h+="<span class='tag' data-id='"+$(this).val()+"'>"+$(this).text()+" </span>"
					});
					$(tags).html(h);
					if(addListeners) app.mobileListeners();
				},
				mobileListeners:function(){
					$(container).find("select").change(function(){
						app.mobileRender();
					});
					$(container).find("select")
						.css("opacity",0)
						.css("position","absolute")
						.css("width","100%")
						.css("left",0);
				},
				resetInput:function(){
					$(container).find("input").val("");
					val = "";
					if(post_key) app.ajax(url);
				},
				renderList:function(){
					var h = "";
					var x =0;
					var self = this;
					$(list).each(function(i,o){
						if(val!="") {
							var reg = new RegExp(val, 'i');
							var match = reg.exec(o.text);
							var split = o.text.split(reg);
						} else {
							split = [o.text];
							match = o.text;
						}
						
						var attr = app.rendAttr(o);
						if (!keys[o.id] && match)  {
							if(x<max) h+="<tr><td "+attr+">"+split.join("<span>"+match+"</span>")+"</td></tr>";
							x++;
						}
					});
					$(container).find(".select-dropdown table").html(h);
					$(container).find(".select-dropdown td").on("mousedown", function(){
						app.change(this);
					});
				},
				 ajax:function(path,query,func){
					var self = this;
					var obj_keys = {};
					if(!query){
						$.get(path).done(function(e) {
							obj = JSON.parse(e);
							$.each(obj, function(i,o){ obj_keys[o.id] = 1});
							$.each(list,function(i,o){
								if(keys[o.id] && !obj_keys[o.id]) obj.push(o);
							});
							
							list = obj;
							app.renderList();
							if(func) func();
						});
					} else {
						$.post(path, query).done(function(e) {
							obj = JSON.parse(e);
							$.each(obj, function(i,o){ obj_keys[o.id] = 1});
							$.each(list,function(i,o){
								if(keys[o.id] && !obj_keys[o.id]) obj.push(o);
							});
							list = obj;
							app.renderList();
							if(func) func();
						});
					}
				},
				rendAttr:function(o){
					var attr = "";
					$.each(o,function(k,b){
						attr+=" data-"+k+"='"+b+"'";
					});
					return attr;
				},
				getAttr:function(el){
					var o = {};
					var tag = $(el).prop("tagName");
					for (const a of $(el)[0].attributes) {
						if(a.name.indexOf("data-")>=0){
							k = a.name.slice(5);
							o[k] = a.value;
						}
					 
					}
					return o;
				}
			}
			
			url = (options.url) ? options.url : url;
    		post_key = (options.post_key) ? options.post_key : post_key;
			if(isMobile) {
				app.mobileRender(true);
			} else {
				if(url) app.ajax(url);
				app.render();
				
			}
    		
   		 });
    }
})(jQuery);

==> keyword-jquery-0.0.151.tgz: package/src/keyword-jquery.js <==
(function($) {
    $.fn.keyword = function(options) {
    	var isMobile = /iPhone|iPad|iPod|Android/i.test(navigator.userAgent);
    	if(!options) options = {};
    	return this.each(function() {
    		var app = {
				change:function(t){
					var v = (val) ? $(t).val() :  $(t).data('id');
					var attr = app.getAttr(t);
					app.update(attr);
				},
				update:function (o){
					var h = "";
					
					keys[o.id] = (keys[o.id]) ? 0 : 1;
					data[o.id] = o;
					
					var self = this;
					$.each(keys,function(id,active){
						//Select vs Multi
						if(!mode && (id!=o.id)) keys[id] = 0; 
						var attr = self.rendAttr(data[id]);
						
						if(keys[id]) h+= "<option value='"+id+"' "+attr+" selected>"+data[id].text+"</option>";
					});

					$(select).html(h);
					val = "";
					$(container).removeClass("active");
					app.resetInput();
					app.render();
					if(change) change(container);
				},
				remove:function (t){
					app.change(t);
				},
				render:function (){
					var htmlSelect = "";
					var htmlTags = "";
					var htmlList = "";
					var x = 0;
					var self = this;
					
					$.each(list,function(i,o){
						var attr = self.rendAttr(o);
						
						if(keys[o.id]) {
							htmlTags+="<span class='tag' "+attr+">"+o.text+" </span>"
						} else {
							if(x<max) htmlList+="<tr><td "+attr+">"+o.text+"</td></tr>";
							x++;
						}
					});	
					
					
					htmlSelect = "<span class='select-container'> <input type='text' placeholder='Select item'/></span><span class='select-dropdown'><table>"+htmlList+"</table></span>";	
					
					$(container).html(htmlTags+htmlSelect);
					$(container).find("input").focus(function(){
						var p = $(this).parent().parent();
						if(!$(p).hasClass("active")) $(p).addClass("active");
					});
					$(container).find("input").blur(function(){
						var p = $(this).parent().parent();
						$(p).removeClass("active");
						app.resetInput();
					});
					$(container).find("input").keyup(function(){
						var v = $(this).val().toLowerCase();
						if(val!=v) {
							val = v;
							if(post_key) {
								var p = {};
								p[post_key] = val;
								app.ajax(url,p,app.renderList);
							} else {
								app.renderList();
							}
							
						}
					});
					$(container).find(".select-dropdown td").on("mousedown", function(){
						app.change(this);
					});
					
					$(container).find(".tag").click(function(){
						app.remove(this);
					});
					
					$(container).find("input")
						//.css("opacity",0)
						.css("position","absolute")
						.css("width","100%")
						.css("left",0);
				},
				mobileRender:function(addListeners){
					var select = $(container).find("select");
					var ids = $(select).val();
					var tags = $(container).find(".tags");
					var h = "";
					$(select).find("option").each(function(i,o){
						if($(this).prop("selected")) h+="<span class='tag' data-id='"+$(this).val()+"'>"+$(this).text()+" </span>"
					});
					$(tags).html(h);
					if(addListeners) app.mobileListeners();
				},
				mobileListeners:function(){
					$(container).find("select").change(function(){
						app.mobileRender();
					});
					$(container).find("select")
						.css("opacity",0)
						.css("position","absolute")
						.css("width","100%")
						.css("left",0);
				},
				resetInput:function(){
					$(container).find("input").val("");
					val = "";
					if(post_key) app.ajax(url);
				},
				renderList:function(){
					
					var h = "";
					var x =0;
					var self = this;
					$(list).each(function(i,o){
						if(val!="") {
							var reg = new RegExp(val, 'i');
							var match = reg.exec(o.text);
							var split = o.text.split(reg);
						} else {
							split = [o.text];
							match = o.text;
						}
						
						var attr = app.rendAttr(o);
						if (!keys[o.id] && match)  {
							if(x<max) h+="<tr><td "+attr+">"+split.join("<span>"+match+"</span>")+"</td></tr>";
							x++;
						}
					});
					$(container).find(".select-dropdown table").html(h);
					$(container).find(".select-dropdown td").on("mousedown", function(){
						app.change(this);
					});
				},
				 ajax:function(path,query,func){
					var self = this;
					var obj_keys = {};
					if(!query){
						$.get(path).done(function(e) {
							obj = JSON.parse(e);
							$.each(obj, function(i,o){ obj_keys[o.id] = 1});
							$.each(list,function(i,o){
								if(keys[o.id] && !obj_keys[o.id]) obj.push(o);
							});
							
							list = obj;
							app.renderList();
							if(func) func();
						});
					} else {
						$.post(path, query).done(function(e) {
							obj = JSON.parse(e);
							$.each(obj, function(i,o){ obj_keys[o.id] = 1});
							$.each(list,function(i,o){
								if(keys[o.id] && !obj_keys[o.id]) obj.push(o);
							});
							
							list = obj;
							app.renderList();
							if(func) func();
						});
					}
				},
				rendAttr:function(o){
					
					var attr = "";
					$.each(o,function(k,b){
						attr+=" data-"+k+"='"+b+"'";
					});
					
					return attr;
				},
				getAttr:function(el){
					var o = {};
					var tag = $(el).prop("tagName");
					for (const a of $(el)[0].attributes) {
						if(a.name.indexOf("data-")>=0){
							k = a.name.slice(5);
							o[k] = a.value;
						}
					 
					}
					return o;
				},
				setFreeText:function(){
					$(document).on('keypress',function(e) {
						if(e.which == 13) {
							var val = $(container).find("input").val();
							if(val!="") {
								//keys[val] = 1;
								var o = {id:val,text:val};
								list.push(o)
								app.update(o);
							}
						}
					});
				}
			}
			
			
    		var id = Math.random().toString(36).substring(4);
    		var select = $(this);
    		var list = [];
    		var keys = {};
    		var data = {};
    		var val = "";
    		var max = 10;
    		var url = 0;
    		var post_key = 0;
    		var free_text = 0;
    		var change = null;
    		var mode = $(this).prop('multiple');
    		
			if(isMobile){
				
			} else {
				var h = "";
				$(select).find("option").each(function(i,o){
					var id = $(this).attr("value");
					var selected = ($(this).attr("selected") && $(this).prop("selected")) ? 1 : 0;
					var datas = app.getAttr(this);
					datas['text']=$(this).html();
					datas['id']=id;
					keys[id] =  selected;
					data[id] = datas;
					
					list.push(data[id]);
					
					var attr = app.rendAttr(datas);
					if(selected) h+="<option value='"+id+"' "+attr+" selected>"+data[id].text+"</option>";
				});	
				
				$(select).html(h);
				var selectHtml = "<span class='select-container'>Select item <input type='text'/></span>";
				select.after('<span class="keyword" id="select-'+id+'"></span>');
				select.css("position","absolute")
					.css("height","0")
					.css("width","0")
					.css("opacity","0");
			}
			var container = $("#select-"+id);
    		
			url = (options.url) ? options.url : url;
			change = (options.change) ? options.change : change;
    		//POST variable used for a query request
    		post_key = (options.post_key) ? options.post_key : post_key;
    		free_text = (options.free_text) ? options.free_text : 0;
			
			if(isMobile) {
				app.mobileRender(true);
			} else {
				if(url) app.ajax(url);
				app.render();
				if(free_text) app.setFreeText();
			}
    		
   		 });
    }
})(jQuery);
